@@ -1,4 +1,3 @@
-
 /* kernel address -> symbol with next lower address.  Charles Blake, 1996.
  * Written to obviate the need for psdatabase initialization based upon kernel
  * binary formats, etc.
@@ -14,6 +13,11 @@
  * would do the trick for this but either makes the file large or truncates
  * symbols.  The approximate method seems to be plenty fast enough, costing
  * only about as much as one extra fstat() or so per process.
+ *
+ * Copyright (C) 1996 Charles Blake
+ * Copyright (C) 1998 Michael K. Johnson
+ * This file may be redistributed under the terms of the
+ * GNU Library General Public License, see ../COPYING.LIB for precise terms.
  */
 #include <stdio.h>
 #include <stdlib.h>
@@ -142,6 +146,7 @@ int open_psdb(void) {
 	"/boot/System.map-%s",
 	"/boot/System.map",
 	"/lib/modules/%s/System.map",
+	"/System.map",
 	NULL
     };
     static char *psdb_paths[] = {
