@@ -1,6 +1,9 @@
 /*
  * New Interface to Process Table -- PROCTAB Stream (a la Directory streams)
- * Copyright(C) 1996. Charles L. Blake.
+ * Copyright (C) 1996 Charles L. Blake.
+ * Copyright (C) 1998 Michael K. Johnson
+ * May be distributed under the conditions of the
+ * GNU Library General Public License; a copy is in ../COPYING.LIB
  */
 #include "proc/version.h"
 #include "proc/readproc.h"
@@ -77,7 +80,7 @@ void stat2proc(char* S, proc_t* P) {
     sscanf(S, "%d (%39c", &P->pid, P->cmd);
     sscanf(tmp + 2,			/* skip space after ')' too */
 	   "%c %d %d %d %d %d %lu %lu %lu %lu %lu %ld %ld %ld %ld %d "
-	   "%d %lu %lu %ld %lu %lu %lu %lu %lu %lu %lu %lu %LX %LX %LX %LX %lu",
+	   "%d %lu %lu %ld %lu %lu %lu %lu %lu %lu %lu %lu %Lu %Lu %Lu %Lu %lu",
 	   &P->state, &P->ppid, &P->pgrp, &P->session, &P->tty, &P->tpgid,
 	   &P->flags, &P->min_flt, &P->cmin_flt, &P->maj_flt, &P->cmaj_flt,
 	   &P->utime, &P->stime, &P->cutime, &P->cstime, &P->priority, &P->nice,
@@ -114,7 +117,10 @@ int file2str(char *directory, char *what, char *ret, int cap) {
 
     sprintf(filename, "%s/%s", directory, what);
     if ( (fd       = open(filename, O_RDONLY, 0)) == -1 ) return -1;
-    if ( (num_read = read(fd, ret, cap - 1))      <= 0 ) return -1;
+    if ( (num_read = read(fd, ret, cap - 1))      <= 0 ) {
+	close (fd);
+	return -1;
+    }
     ret[num_read] = 0;
     close(fd);
     return num_read;
@@ -257,7 +263,10 @@ next_proc:				/* get next PID for consideration */
     if (Do(FILLMEM)) {				/* read, parse /proc/#/statm */
 	if ((file2str(path, "statm", sbuf, sizeof sbuf)) != -1 )
 	    statm2proc(sbuf, p);		/* ignore statm errors here */
-    }						/* statm fields just zero */
+	else					/* statm fields just zero */
+	    p->size = p->resident = p->share = p->trs =
+		p->lrs = p->drs = p->dt = 0.0;	/* rbuf not necessarily 0 */
+    }
 
     /* some number->text resolving which is time consuming */
     if (Do(FILLTTY))
