@@ -245,8 +245,10 @@ void setup_terminal(void)
 {
     char *termtype;
     struct termios newtty;
-
-    termtype = getenv("TERM");
+    if (!Batch)
+    	termtype = getenv("TERM");
+    else 
+	termtype = "dumb";
     if (!termtype) {
 	/* In theory, $TERM should never not be set, but in practice,
 	   some gettys don't.  Fortunately, vt100 is nearly always
@@ -330,6 +332,22 @@ int main(int argc, char **argv)
 		    exit(1);
 		}
 		break;
+	      case 'n':
+		if (cp[1]) {
+	   	    if (sscanf(++cp, "%d", &Loops) != 1) {
+			fprintf(stderr, PROGNAME ": Bad value `%s'\n", cp);
+			exit(1);
+		    }
+		    goto breakargv;
+		} else if (*argv) { /* last char in an argv, use next as arg */
+		    if (sscanf(cp = *argv++, "%d", &Loops) != 1) {
+			fprintf(stderr, PROGNAME ": Bad value `%s'\n", cp);
+			 exit(1);
+	 	     }
+		     goto breakargv;
+		}
+		break;
+					
 	      case 'q':
 		if (!getuid())
 		    /* set priority to -10 in order to stay above kswapd */
@@ -340,6 +358,9 @@ int main(int argc, char **argv)
 		    }
 		Sleeptime = 0;
 		break;
+	      case 'b':
+		Batch = 1;
+	        break;
 	      case 'c':
 	        show_cmd = !show_cmd;
 		break;
@@ -398,15 +419,24 @@ int main(int argc, char **argv)
 
     /* loop, collecting process info and sleeping */
     while (1) {
+	if (Loops > 0)
+		Loops--;
 	/* display the tasks */
 	show_procs();
 	/* sleep & wait for keyboard input */
-	tv.tv_sec = Sleeptime;
-	tv.tv_usec = (Sleeptime - (int) Sleeptime) * 1000000;
-	FD_ZERO(&in);
-	FD_SET(0, &in);
-	if (select(1, &in, 0, 0, &tv) > 0 && read(0, &c, 1) == 1)
-	    do_key(c);
+	if (Loops == 0)
+	    end(0);
+        if (!Batch)
+        {
+		tv.tv_sec = Sleeptime;
+		tv.tv_usec = (Sleeptime - (int) Sleeptime) * 1000000;
+		FD_ZERO(&in);
+		FD_SET(0, &in);
+		if (select(1, &in, 0, 0, &tv) > 0 && read(0, &c, 1) == 1)
+	    		do_key(c);
+        } else {
+	   sleep(Sleeptime);
+	}
     }
 }
 
@@ -453,7 +483,7 @@ void stop(int signo)
     fflush(stdout);
     raise(SIGSTOP);
     /* Later... */
-    ioctl(0, TCSAFLUSH, &Rawtty);
+    tcsetattr(0, TCSAFLUSH, &Rawtty);
 }
 
 /*
@@ -472,11 +502,12 @@ void window_size(int signo)
 	Cols = tgetnum("co");
 	Lines = tgetnum("li");
     }
-    clear_screen();
+    if (!Batch)
+        clear_screen();
     /*
      * calculate header size, length of cmdline field ...
      */
-    Numfields = make_header();
+     Numfields = make_header();
 }
 /*
        * this adjusts the lines needed for the header to the current value
@@ -941,6 +972,7 @@ void show_task_info(proc_t *task, int pmem)
 	    if (!show_cmd && task->cmdline && *(task->cmdline)) {
 	        j=0;
 	        while(((task->cmdline)[j] != NULL) && (strlen(tmp3)<1024)) {
+		    strcat(tmp3, " ");
 		    strncat(tmp3, (task->cmdline)[j], 1023);
 		    j++; 
 	        }
@@ -1003,6 +1035,8 @@ void show_procs(void)
 	sleep(1);
 	first=1;
     }
+    if (first && Batch)
+	    fputs("\n\n",stdout);
     /* Display the load averages. */
     PUTP(ho);
     PUTP(md);
@@ -1046,7 +1080,8 @@ void show_procs(void)
 	     */
 	    pmem = p_table[count]->resident * 1000 / (main_mem / 4096);
 	    show_task_info(p_table[count], pmem);
-	    ActualLines++;
+	    if (!Batch)
+	    	ActualLines++;
 	}
 	count++;
     }
