@@ -102,6 +102,8 @@ int show_stats = 1;    /* show status summary */
 int show_memory = 1;   /* show memory summary */
 int show_loadav = 1;   /* show load average and uptime */
 int show_cmd = 1;      /* show command name instead of commandline */
+int Loops = -1;	       /* number of iterations. -1 loops forever */
+int Batch = 0;         /* batch mode. Collect no input, dumb output */
 
 /* sorting order: cpu%, mem, time (cumulative, if in cumulative mode) */
 enum {
