@@ -40,10 +40,9 @@ void    print_logintime(time_t login_time, FILE* fout);
 #define USERSZ (sizeof u->ut_user)
 
 int main(int argc, char **argv) {
-    int header=1, longform=1, from=1, args, maxcmd = 80, fd;
-    char ch, *user = NULL;
-    utmp_t *u, *last;
-    struct stat sbuf;
+    int header=1, longform=1, from=1, args, maxcmd = 80, ch;
+    char *user = NULL;
+    utmp_t *u;
     struct winsize win;
 
 #ifndef W_SHOWFROM
@@ -70,8 +69,8 @@ int main(int argc, char **argv) {
 	    exit(1);
 	}
 
-    if ((argv[args ? 2 : 1]))
-	user = (argv[args ? 2 : 1]);	/* This is WRONG. FIXME. */
+    if ((argv[optind]))
+	user = (argv[optind]);
 
     if (ioctl(1, TIOCGWINSZ, &win) != -1 && win.ws_col > 0)
 	maxcmd = win.ws_col;
@@ -155,8 +154,8 @@ time_t idletime(utmp_t *u, char *tty) {
 }
 
 void showinfo(utmp_t *u, int formtype, int maxcmd, int from) {
-    int jcpu, pcpu, i, ut_pid_found;
-    char cmd[maxcmd + 1], uname[USERSZ + 1] = "",
+    int jcpu, i, ut_pid_found;
+    char uname[USERSZ + 1] = "",
 	tty[5 + sizeof u->ut_line + 1] = "/dev/";
     proc_t *best;
 
@@ -201,13 +200,14 @@ void showinfo(utmp_t *u, int formtype, int maxcmd, int from) {
 	    print_time_ival7(idletime(u, tty), 0, stdout);
     }
     fputs("  ", stdout);
-    if (best)
+    if (best) {
 	if (best->cmdline)
 	    print_strlist(stdout, best->cmdline, " ", maxcmd);
 	else
 	    printf("%*.*s", maxcmd, maxcmd, best->cmd);
-    else
+    } else {
 	printf("-");
+    }
     fputc('\n', stdout);
 }
 
@@ -231,14 +231,15 @@ void print_logintime(time_t logt, FILE* fout) {
     merid = (hour < 12) ? "am" : "pm";
     if (hour >= 12) hour -= 12;
     if (hour == 0)  hour = 12;
-    if (curt - logt > 12*60*60 && logtm->tm_yday != today)
+    if (curt - logt > 12*60*60 && logtm->tm_yday != today) {
 	if (curt - logt > 6*24*60*60)
 	    fprintf(fout, " %2d%3s%2d", logtm->tm_mday, month[logtm->tm_mon],
 		    logtm->tm_year % 100);
 	else
 	    fprintf(fout, " %3s%2d%s", weekday[logtm->tm_wday], hour, merid);
-    else
+    } else {
 	fprintf(fout, " %2d:%02d%s", hour, logtm->tm_min, merid);
+    }
 }
 
 /* This function scans the process table accumulating total cpu times for
